@@ -1,7 +1,6 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
-#
-# Powered by the Bokeh Development Team.
+# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
@@ -99,6 +98,7 @@ Basic Properties
 .. autoclass:: Regex
 .. autoclass:: Size
 .. autoclass:: String
+.. autoclass:: Struct
 .. autoclass:: TimeDelta
 
 Container Properties
@@ -187,6 +187,7 @@ __all__ = (
     'Bool',
     'Byte',
     'Color',
+    'ColorHex',
     'ColorSpec',
     'ColumnData',
     'Complex',
@@ -202,6 +203,8 @@ __all__ = (
     'Float',
     'FontSize',
     'FontSizeSpec',
+    'HatchPatternSpec',
+    'HatchPatternType',
     'Image',
     'Include',
     'Instance',
@@ -223,6 +226,7 @@ __all__ = (
     'Size',
     'String',
     'StringSpec',
+    'Struct',
     'TimeDelta',
     'Tuple',
     'UnitsSpec',
@@ -244,6 +248,7 @@ from .property.auto import Auto; Auto
 
 from .property.color import Color; Color
 from .property.color import RGB; RGB
+from .property.color import ColorHex; ColorHex
 
 from .property.container import Array; Array
 from .property.container import ColumnData; ColumnData
@@ -261,6 +266,7 @@ from .property.dataspec import DistanceSpec; DistanceSpec
 from .property.dataspec import expr; expr
 from .property.dataspec import field; field
 from .property.dataspec import FontSizeSpec; FontSizeSpec
+from .property.dataspec import HatchPatternSpec; HatchPatternSpec
 from .property.dataspec import MarkerSpec; MarkerSpec
 from .property.dataspec import NumberSpec; NumberSpec
 from .property.dataspec import ScreenDistanceSpec; ScreenDistanceSpec
@@ -285,6 +291,7 @@ from .property.json import JSON; JSON
 from .property.numeric import Angle; Angle
 from .property.numeric import Byte; Byte
 from .property.numeric import Interval; Interval
+from .property.numeric import NonNegativeInt; NonNegativeInt
 from .property.numeric import Percent; Percent
 from .property.numeric import Size; Size
 
@@ -298,8 +305,11 @@ from .property.primitive import String; String
 
 from .property.regex import Regex; Regex
 
+from .property.struct import Struct; Struct
+
 from .property.visual import DashPattern; DashPattern
 from .property.visual import FontSize; FontSize
+from .property.visual import HatchPatternType; HatchPatternType
 from .property.visual import Image; Image
 from .property.visual import MinMaxBounds; MinMaxBounds
 from .property.visual import MarkerType; MarkerType
