@@ -19,6 +19,7 @@ import pytest ; pytest
 # Standard library imports
 
 # External imports
+import six
 
 # Bokeh imports
 from bokeh.colors import named
@@ -62,6 +63,16 @@ class Test_enumeration(object):
             assert x in e
         assert "junk" not in e
 
+    @pytest.mark.skipif(six.PY2, reason="Unimportant uicode silliness, py2 going away soon")
+    def test_quote(self):
+        e = bce.enumeration("foo", "bar", "baz", quote=True)
+        assert isinstance(e, bce.Enumeration)
+        assert str(e) == 'Enumeration("foo", "bar", "baz")' or str(e) == "Enumeration('foo', 'bar', 'baz')"
+        assert [x for x in e] == ["foo", "bar", "baz"]
+        for x in ["foo", "bar", "baz"]:
+            assert x in e
+        assert "junk" not in e
+
     def test_default(self):
         # this is private but used by properties
         e = bce.enumeration("foo", "bar", "baz")
@@ -109,6 +120,16 @@ class Test_bce(object):
     def test_FontStyle(self):
         assert tuple(bce.FontStyle) == ('normal', 'italic', 'bold', 'bold italic')
 
+    def test_HatchPattern(self):
+        assert tuple(bce.HatchPattern) == (
+            "blank", "dot", "ring", "horizontal_line", "vertical_line", "cross", "horizontal_dash", "vertical_dash",
+            "spiral", "right_diagonal_line", "left_diagonal_line", "diagonal_cross", "right_diagonal_dash",
+            "left_diagonal_dash", "horizontal_wave", "vertical_wave", "criss_cross"
+        )
+
+    def test_HatchPatternAbbreviation(self):
+        assert tuple(bce.HatchPatternAbbreviation) ==(' ', '.', 'o', '-', '|', '+', '"', ':', '@', '/', '\\', 'x', ',', '`', 'v', '>', '*')
+
     def test_HoldPolicy(self):
         assert tuple(bce.HoldPolicy) == ("combine", "collect")
 
@@ -179,6 +200,9 @@ class Test_bce(object):
     def test_RenderMode(self):
         assert tuple(bce.RenderMode) == ("canvas", "css")
 
+    def test_ResetPolicy(self):
+        assert tuple(bce.ResetPolicy) == ("standard", "event_only")
+
     def test_RoundingFunction(self):
         assert tuple(bce.RoundingFunction) == ("round", "nearest", "floor", "rounddown", "ceil", "roundup")
 
@@ -206,6 +230,9 @@ class Test_bce(object):
     def test_TextBaseline(self):
         assert tuple(bce.TextBaseline) == ("top", "middle", "bottom", "alphabetic", "hanging", "ideographic")
 
+    def test_TextureRepetition(self):
+        assert tuple(bce.TextureRepetition) == ("repeat", "repeat_x", "repeat_y", "no_repeat")
+
     def test_TickLabelOrientation(self):
         assert tuple(bce.TickLabelOrientation) == ("horizontal", "vertical", "parallel", "normal")
 
@@ -236,6 +263,8 @@ def test_enums_contents():
         'Direction',
         'Enumeration',
         'FontStyle',
+        'HatchPattern',
+        'HatchPatternAbbreviation',
         'HoldPolicy',
         'HorizontalLocation',
         'JitterRandomDistribution',
@@ -256,6 +285,7 @@ def test_enums_contents():
         'Palette',
         'RenderLevel',
         'RenderMode',
+        'ResetPolicy',
         'RoundingFunction',
         'SizingMode',
         'SizingPolicy',
@@ -266,6 +296,7 @@ def test_enums_contents():
         'StepMode',
         'TextAlign',
         'TextBaseline',
+        'TextureRepetition',
         'TickLabelOrientation',
         'TooltipAttachment',
         'TooltipFieldFormatter',
