@@ -161,7 +161,7 @@ class BaseServer(object):
             None
 
         '''
-        self._http.close_all_connections()
+        yield self._http.close_all_connections()
         self._http.stop()
 
     def run_until_shutdown(self):
@@ -364,6 +364,7 @@ class Server(BaseServer):
         self._port = opts.port
         self._address = opts.address
         self._prefix = opts.prefix
+        self._index = opts.index
 
         if opts.num_procs != 1:
             assert all(app.safe_to_fork for app in applications.values()), (
@@ -389,6 +390,7 @@ class Server(BaseServer):
             tornado_app = BokehTornado(applications,
                                        extra_websocket_origins=extra_websocket_origins,
                                        prefix=self.prefix,
+                                       index=self.index,
                                        websocket_max_message_size_bytes=opts.websocket_max_message_size,
                                        **kwargs)
 
@@ -408,6 +410,13 @@ class Server(BaseServer):
 
         super(Server, self).__init__(io_loop, tornado_app, http_server)
 
+    @property
+    def index(self):
+        ''' A path to a Jinja2 template to use for index at "/"
+
+        '''
+        return self._index
+
     @property
     def prefix(self):
         ''' The configured URL prefix to use for all Bokeh server paths.
@@ -464,6 +473,10 @@ class _ServerOpts(Options):
     A URL prefix to use for all Bokeh server paths.
     """)
 
+    index = String(default=None, help="""
+    A path to a Jinja2 template to use for the index "/"
+    """)
+
     allow_websocket_origin = List(String, default=None, help="""
     A list of hosts that can connect to the websocket.
 
