@@ -1,7 +1,6 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2017, Anaconda, Inc. All rights reserved.
-#
-# Powered by the Bokeh Development Team.
+# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
@@ -33,15 +32,15 @@ from ..core.has_props import HasProps
 # Globals and constants
 #-----------------------------------------------------------------------------
 
-__all__ = (
-    'Theme',
-)
-
 # whenever we cache that there's nothing themed for a class, we
 # use this same dict instance, so we don't have a zillion empty
 # dicts in our caches.
 _empty_dict = dict()
 
+__all__ = (
+    'Theme',
+)
+
 #-----------------------------------------------------------------------------
 # General API
 #----------------------------------------------------------------------------
@@ -128,7 +127,7 @@ class Theme(object):
         if filename is not None:
             f = open(filename)
             try:
-                json = yaml.load(f)
+                json = yaml.safe_load(f)
                 # empty docs result in None rather than {}, fix it.
                 if json is None:
                     json = {}
