@@ -1,11 +1,11 @@
 from bokeh.plotting import figure, show, output_file
-from bokeh.tile_providers import CARTODBPOSITRON
+from bokeh.tile_providers import get_provider, Vendors
 
 output_file("tile_source.html")
 
 # create plot and add tools
 p = figure(x_range=(-2000000, 2000000), y_range=(1000000, 7000000),
            x_axis_type="mercator", y_axis_type="mercator")
-p.add_tile(CARTODBPOSITRON)
+p.add_tile(get_provider(Vendors.CARTODBPOSITRON))
 
 show(p)
