@@ -16,7 +16,7 @@ source = ColumnDataSource(dict(x=x, y=y))
 
 plot = Plot(
     title=None, plot_width=300, plot_height=300,
-    h_symmetry=False, v_symmetry=False, min_border=0, toolbar_location=None)
+    min_border=0, toolbar_location=None)
 
 glyph = Patch(x="x", y="y", fill_color="#a6cee3")
 plot.add_glyph(source, glyph)
