@@ -4,11 +4,12 @@ from bokeh.plotting import figure
 output_file("bars.html")
 
 fruits = ['Apples', 'Pears', 'Nectarines', 'Plums', 'Grapes', 'Strawberries']
+counts = [5, 3, 4, 2, 4, 6]
 
 p = figure(x_range=fruits, plot_height=250, title="Fruit Counts",
            toolbar_location=None, tools="")
 
-p.vbar(x=fruits, top=[5, 3, 4, 2, 4, 6], width=0.9)
+p.vbar(x=fruits, top=counts, width=0.9)
 
 p.xgrid.grid_line_color = None
 p.y_range.start = 0
