@@ -1,5 +1,4 @@
 from bokeh.io import output_file, show
-from bokeh.layouts import widgetbox
 from bokeh.models.widgets import CheckboxGroup
 
 output_file("checkbox_group.html")
@@ -7,4 +6,4 @@ output_file("checkbox_group.html")
 checkbox_group = CheckboxGroup(
         labels=["Option 1", "Option 2", "Option 3"], active=[0, 1])
 
-show(widgetbox(checkbox_group))
+show(checkbox_group)
