@@ -1,5 +1,4 @@
 from bokeh.io import output_file, show
-from bokeh.layouts import widgetbox
 from bokeh.models.widgets import RadioButtonGroup
 
 output_file("radio_button_group.html")
@@ -7,4 +6,4 @@ output_file("radio_button_group.html")
 radio_button_group = RadioButtonGroup(
         labels=["Option 1", "Option 2", "Option 3"], active=0)
 
-show(widgetbox(radio_button_group))
+show(radio_button_group)
