@@ -1,4 +1,4 @@
-from bokeh.models.widgets import Panel, Tabs
+from bokeh.models import Panel, Tabs
 from bokeh.io import output_file, show
 from bokeh.plotting import figure
 
