@@ -1,6 +1,6 @@
 from bokeh.plotting import figure, output_file, show
 
-output_file("gridbands.html")
+output_file("grid_band_fill.html")
 
 p = figure(plot_width=400, plot_height=400)
 p.circle([1,2,3,4,5], [2,5,8,2,7], size=10)
